@@ -55,7 +55,7 @@ int shiftin_cnt;
 /* current block */
 struct block *shiftin_blk;
 
-int shiftin()
+void shiftin()
 {
 	int n;
 
@@ -75,8 +75,6 @@ int shiftin()
 	} else {	
 		t[T_SIZE-1]=-1;
 	}
-
-	return(t[T_SIZE]);
 }
 
 /* Returns:
@@ -150,7 +148,7 @@ int ckrange_rel(int skip, int pc, char *str)
 			val=pc+2+t[skip]-256;
 		}
 
-		symb=symbol_find(val);
+		symb=symbol_find(val & 0xffff);
 	}
 
 	if(a_labels && symb!=NULL) {
